@@ -1,27 +1,26 @@
 
 from .so4gp import DataGP
+from .so4gp import DataGP4clu
 from .so4gp import GI
 from .so4gp import GP
+from .so4gp import GP4sw
+from .so4gp import NumericSS
 from .so4gp import TimeLag
+
+from .so4gp import gen_d
+from .so4gp import gen_apriori_candidates
+from .so4gp import gen_aco_candidates
 from .so4gp import inv
 
-from .so4gp import gend
-from .so4gp import genapri
-from .so4gp import genaco
-
-from .so4gp import validategp
-from .so4gp import isduplicate
-from .so4gp import amcheck
-from .so4gp import decodegp
-from .so4gp import costfxn
-
-from .so4gp import graank
 from .so4gp import acogps
-from .so4gp import gagps
-from .so4gp import psogps
+from .so4gp import clugps
 from .so4gp import hcgps
+from .so4gp import gagps
+from .so4gp import graank
+from .so4gp import psogps
 from .so4gp import rsgps
 
+from .so4gp import compare_gps
 from .so4gp import get_num_cores
 from .so4gp import get_slurm_cores
 from .so4gp import write_file
